=========================
Management Operations
=========================

.. module:: couchbase.management

The :module:`~.couchbase.management` provides several convenience methods
to perform common API requests.

.. warning:: The interface here is provided as a convenience only
    and its interface may change.


.. module:: couchbase.management.collections

.. autoclass:: CollectionManager
    :members:

.. module:: couchbase.management.buckets

.. autoclass:: BucketManager
    :members:


.. module:: couchbase.management.users

.. autoclass:: UserManager
    :members:

.. module:: couchbase.management.queries

.. autoclass:: QueryIndexManager
    :members:

